@@ -3,6 +3,7 @@ from __future__ import annotations
 
 from typing import Literal, TypedDict
 
+from ...const import RemoveNodeReason
 from ...event import BaseEventModel
 from ..node.data_model import FoundNodeDataType, NodeDataType
 from .firmware import (
@@ -65,18 +66,18 @@ class GrantSecurityClassesEventModel(BaseControllerEventModel):
     requested: InclusionGrantDataType
 
 
-class HealNetworkDoneEventModel(BaseControllerEventModel):
-    """Model for `heal network done` event data."""
+class RebuildRoutesDoneEventModel(BaseControllerEventModel):
+    """Model for `rebuild routes done` event data."""
 
-    event: Literal["heal network done"]
-    result: dict[int, str]
+    event: Literal["rebuild routes done"]
+    result: dict[str, str]
 
 
-class HealNetworkProgressEventModel(BaseControllerEventModel):
-    """Model for `heal network progress` event data."""
+class RebuildRoutesProgressEventModel(BaseControllerEventModel):
+    """Model for `rebuild routes progress` event data."""
 
-    event: Literal["heal network progress"]
-    progress: dict[int, str]
+    event: Literal["rebuild routes progress"]
+    progress: dict[str, str]
 
 
 class InclusionAbortedEventModel(BaseControllerEventModel):
@@ -124,7 +125,7 @@ class NodeRemovedEventModel(BaseControllerEventModel):
 
     event: Literal["node removed"]
     node: NodeDataType
-    replaced: bool
+    reason: RemoveNodeReason
 
 
 class NVMBackupAndConvertProgressEventModel(BaseControllerEventModel):
@@ -168,15 +169,30 @@ class ValidateDSKAndEnterPINEventModel(BaseControllerEventModel):
     dsk: str
 
 
-CONTROLLER_EVENT_MODEL_MAP: dict[str, type["BaseControllerEventModel"]] = {
+class IdentifyEventModel(BaseControllerEventModel):
+    """Model for `identify` event data."""
+
+    event: Literal["identify"]
+    nodeId: int
+
+
+class StatusChangedEventModel(BaseControllerEventModel):
+    """Model for `status changed` event data."""
+
+    event: Literal["status changed"]
+    status: int
+
+
+CONTROLLER_EVENT_MODEL_MAP: dict[str, type[BaseControllerEventModel]] = {
     "exclusion failed": ExclusionFailedEventModel,
     "exclusion started": ExclusionStartedEventModel,
     "exclusion stopped": ExclusionStoppedEventModel,
     "firmware update finished": FirmwareUpdateFinishedEventModel,
     "firmware update progress": FirmwareUpdateProgressEventModel,
     "grant security classes": GrantSecurityClassesEventModel,
-    "heal network done": HealNetworkDoneEventModel,
-    "heal network progress": HealNetworkProgressEventModel,
+    "rebuild routes done": RebuildRoutesDoneEventModel,
+    "rebuild routes progress": RebuildRoutesProgressEventModel,
+    "identify": IdentifyEventModel,
     "inclusion aborted": InclusionAbortedEventModel,
     "inclusion failed": InclusionFailedEventModel,
     "inclusion started": InclusionStartedEventModel,
@@ -188,5 +204,6 @@ CONTROLLER_EVENT_MODEL_MAP: dict[str, type["BaseControllerEventModel"]] = {
     "nvm convert progress": NVMConvertProgressEventModel,
     "nvm restore progress": NVMRestoreProgressEventModel,
     "statistics updated": StatisticsUpdatedEventModel,
+    "status changed": StatusChangedEventModel,
     "validate dsk and enter pin": ValidateDSKAndEnterPINEventModel,
 }
